
TODO: TODO_10_72_28_05: Simpler `help` config for any number of commands.

It also applies to `intercept` and `query_.

# The point

Configuring commands like `help`, `intercept`, `enum` is still seems cumbersome and error-prone:

*   The delegators for these funcs has to provide `single_func_id` in their config.

    This is required to find places where these funcs plug into the tree to
    build `tree_abs_path_to_interp_id` from FS_33_76_82_84 composite forest.

*   However, there is no validation whether func from that `single_fund_id` is configured correctly.

    The FS_33_76_82_84 composite forest has to have nested nodes with single function there:

    ```yaml
    "help":
        node_type: interp_tree_node
        plugin_instance_id: FuncTreeInterpFactory.default
        sub_tree:
            "":
                node_type: func_tree_node
                func_id: func_id_help_hint
    ```

    And this config has to be duplicated for all places where "help" is plugged into.

# Why do we need `FuncTreeInterpFactory` interp wrapping single-func sub-tree with single `func_tree_node`?

We use dedicated instance of `FuncTreeInterpFactory` for these special funcs to terminate search of
interpreter within FS_01_89_09_24 interp tree.

But we still need to find that specific special func (not an interpreter) to do anything - that is why
there is FS_26_43_73_72 func tree with that single func.

Only when that specific special func is selected, FS_91_88_07_23 jump tree is used to restart search
for the func which will be controlled by the special func.

It is a bit cumbersome to reason about and configure, but it works as required.
To be fair, there are not many meta functions like `intercept` or `help` (which also uses that).

See also:
*   TODO_06_54_83_58 extend via func instead of delegator
